"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaskAttemptBrowser = void 0;
const react_1 = __importDefault(require("react"));
const polaris_1 = require("@shopify/polaris");
const hooks_1 = require("../hooks");
const StatusBadge_1 = require("./StatusBadge");
const TaskLogViewer_1 = require("./TaskLogViewer");
const TaskAttemptBrowser = ({ taskRef }) => {
    const { taskAttempts } = hooks_1.useTaskAttempts(taskRef);
    const [selectedTaskAttemptId, setSelectedTaskAttemptId] = react_1.default.useState();
    const handleTaskAttemptClick = react_1.default.useCallback((e) => {
        e.preventDefault();
        setSelectedTaskAttemptId(e.currentTarget.dataset.taskAttemptId);
    }, []);
    const selectedTaskAttempt = react_1.default.useMemo(() => {
        var _a;
        return ((_a = taskAttempts === null || taskAttempts === void 0 ? void 0 : taskAttempts.find(({ id }) => id === selectedTaskAttemptId)) !== null && _a !== void 0 ? _a : taskAttempts === null || taskAttempts === void 0 ? void 0 : taskAttempts[0]);
    }, [taskAttempts, selectedTaskAttemptId]);
    // select the first attempt when a new attempt is added
    react_1.default.useMemo(() => setSelectedTaskAttemptId(undefined), [taskAttempts === null || taskAttempts === void 0 ? void 0 : taskAttempts.length]);
    return (react_1.default.createElement(polaris_1.Stack, { spacing: "none", wrap: false },
        react_1.default.createElement(polaris_1.Stack.Item, null,
            react_1.default.createElement(polaris_1.Stack, { vertical: true },
                react_1.default.createElement(polaris_1.Heading, null, "Attempts"),
                react_1.default.createElement("div", { className: "taskify-attempt-selector" },
                    !selectedTaskAttempt && (react_1.default.createElement("div", { className: "taskify-attempt-selector__btn taskify-attempt-selector__btn--active" },
                        react_1.default.createElement(polaris_1.Stack, null,
                            react_1.default.createElement(polaris_1.Spinner, { size: "small" }),
                            react_1.default.createElement("p", null, "Loading attempts\u2026")))),
                    !!taskAttempts &&
                        !!selectedTaskAttempt &&
                        taskAttempts.map((taskAttempt, n) => (react_1.default.createElement("a", { href: "#", onClick: handleTaskAttemptClick, className: [
                                "taskify-attempt-selector__btn",
                                taskAttempt.id === selectedTaskAttempt.id &&
                                    "taskify-attempt-selector__btn--active",
                            ]
                                .filter(Boolean)
                                .join(" "), key: `${taskAttempt.id}`, "data-task-attempt-id": taskAttempt.id },
                            react_1.default.createElement(polaris_1.Stack, null,
                                react_1.default.createElement(polaris_1.TextContainer, null,
                                    "Attempt #",
                                    taskAttempts.length - n),
                                react_1.default.createElement(StatusBadge_1.StatusBadge, { status: taskAttempt.status })))))))),
        react_1.default.createElement(polaris_1.Stack.Item, { fill: true },
            react_1.default.createElement(polaris_1.Stack, { vertical: true },
                react_1.default.createElement(polaris_1.Heading, null, "Logs"),
                react_1.default.createElement(TaskLogViewer_1.TaskLogViewer, { taskAttemptRef: selectedTaskAttempt === null || selectedTaskAttempt === void 0 ? void 0 : selectedTaskAttempt.ref })))));
};
exports.TaskAttemptBrowser = TaskAttemptBrowser;
